def compute_sum(params, data, target_shortname):

	if len(params) == 0 or len(data) == 0 :
		return None
	
	res = []
	
	for param in params:	

		fs = mv.read(data = data, param = param)

		if len(fs) == 0:
			return None

		if len(res) == 0:
			res = fs
		else:
			res += fs

	# set correct shortname for result
	res = mv.grib_set_string(res, ["shortName", target_shortname])

	# mark as non-drived field - so that the correct scaling could be applied in contouring
	res = mv.grib_set_long(res, ["generatingProcessIdentifier", 149])
    
	return res



#***************************** LICENSE START ***********************************
#
# Copyright 2018 ECMWF and INPE. This software is distributed under the terms
# of the Apache License version 2.0. In applying this license, ECMWF does not
# waive the privileges and immunities granted to it by virtue of its status as
# an Intergovernmental Organization or submit itself to any jurisdiction.
#
# ***************************** LICENSE END *************************************

import json
import sys
import os
import datetime

script_command_prefix = {"macro": "","python": "mv."}
script_param_assign_char = {"macro": ":","python": "="}
script_translate_class_param = { "macro": "class", "python": "class_"}
script_file_suffix = {"macro": ".mv","python": ".py"}


def load_json_mars(mars_file):
    """ Reads json file and returns dictionary """
    with open(mars_file, 'r') as defs:
        dictionary_of_defs = json.load(defs)
    return dictionary_of_defs


def load_json_layer(layer_file):
    """ Reads json file and returns dictionary """

    with open(layer_file, 'r') as defs:
        dictionary_of_defs = json.load(defs)
    return dictionary_of_defs


def build_title_request(main_title, short_name):
    """ Generate Metview request for title """

    start_text = "<grib_info key=\\'base-date\\' format=\\'%d.%m.%Y. %H\\' where=\\'shortName=" \
                 + short_name + "\\' /> UTC"
    step_text = "<grib_info key=\\'step\\' where=\\'shortName=" + short_name + "\\' />h"
    valid_text = "<grib_info key=\\'valid-date\\' format=\\'%d.%m.%Y. %H\\' where=\\'shortName=" + short_name \
                 + "\\' /> UTC"

    title = "MTEXT,\n" \
        + " TEXT_LINE_1 = '" + main_title + "  START: " + start_text + "   STEP: " + step_text \
        + "  VALID FOR: " + valid_text + "',\n" \
        + " TEXT_COLOUR = CHARCOAL"

    return title


def build_title_script(main_title, short_name, mode):
    """ Generate script code for title """

    start_text = "<grib_info key='base-date' format='%d.%m.%Y. %H' where='shortName=" \
                 + short_name + "' /> UTC"
    step_text = "<grib_info key='step' where='shortName=" + short_name + "' />h"
    valid_text = "<grib_info key='valid-date' format='%d.%m.%Y. %H' where='shortName=" + short_name \
                 + "' /> UTC"

    sep = script_param_assign_char[mode]

    title = script_command_prefix[mode] + "mtext(\n" \
        + "    text_line_1 " + sep + " \"" + main_title + "  START: " + start_text + "  STEP:  " + step_text \
        + "  VALID FOR =  " + valid_text + "\",\n" \
        + "    text_colour " + sep + " \"charcoal\")"

    return title


def build_visdef_request(style_name):
    """ Generate Metview request for contouring """

    visdef = "MCONT,\n" \
        + " CONTOUR_AUTOMATIC_SETTING = STYLE_NAME, \n" \
        + " CONTOUR_STYLE_NAME = " + style_name + ",\n" \
        + " LEGEND = ON"

    return visdef


def build_visdef_script(style_name, mode):
    """ Generate script code for contouring """

    sep = script_param_assign_char[mode]

    visdef = script_command_prefix[mode] + "mcont(\n" \
        + "    contour_automatic_setting " + sep + " \"style_name\",\n" \
        + "    contour_style_name " + sep + "        \"" + style_name + "\",\n" \
        + "    legend " +  sep + "                   \"on\")"

    return visdef


def build_legend_request():
    """ Generate Metview request for legend """

    legend_req = "MLEGEND,\n" \
        + " LEGEND_TEXT_COLOUR = CHARCOAL"

    return legend_req


def build_legend_script(mode):
    """ Generate script code for legend """

    sep = script_param_assign_char[mode]

    legend = script_command_prefix[mode] + "mlegend(\n" \
        + "    legend_text_colour " + sep +" \"charcoal\")"

    return legend


def build_mars_script(mars, mode):
    """ Generate code for MARS request """

    sep = script_param_assign_char[mode]

    text_for_mars = script_command_prefix[mode] + 'retrieve(\n'
    for key in mars:
        v = mars[key]

        if type(v) == str:

            if not v.startswith('[') or not v.endswith(']'):
                v = "'" + v + "'"

        if key == "class" :
            key = script_translate_class_param[mode]

        text_for_mars += '    ' + str(key) + ' ' + sep + ' ' + str(v) + ',\n'

    text_for_mars = text_for_mars[:-2]
    text_for_mars += ')'
    return text_for_mars


def build_pproc_script_call(mars, pproc_func, short_name, pproc_func_extra_args, mode):
    """ Generate code for calling post-processing of retrieved fields """

    params = mars["param"]
    if type(params) == list:
        params_str = ", ".join(['\"' + s + '\"' for s in params])
        # params_str = ", ".join(params)
        params_str = '[' + params_str + ']'
    else:
        params_str = '[' + params + ']'

    text_for_mars = pproc_func + '(' + params_str + ', data , \"' + short_name + "\""
    for a in pproc_func_extra_args:
        text_for_mars += ', ' + a

    text_for_mars += ')'

    return text_for_mars


def build_pproc_script_code(pproc_func, mode):
    """ Generate code for post-processing of retrieved fields """

    suffix = script_file_suffix[mode]
    filename = os.environ["METVIEW_DIR_SHARE"] + "/eccharts/scripts/" + pproc_func + suffix
    with open(filename, 'r') as fp:
        return fp.read()


def steps_for_interval(step_str, interval, layer_name):

    # define the available steps in MARS
    if layer_name in {'mn2t', 'mx2t', '10m_fg_interval'}:
        all_steps = list(range(0, 91))
        all_steps.extend(list(range(93, 147, 3)))
        all_steps.extend(list(range(150, 246, 6)))
    else:
        return ""

    # convert the steps into an integer list
    if not step_str.startswith('[') or not step_str.endswith(']'):
        print("\'step\' is not formatted as a list:", step_str)
        sys.exit(1)

    steps = step_str[1:-1].split(",")
    print("steps=", steps)
    steps = [int(i) for i in steps]
    print("steps=", steps)

    # define the steps for the given interval
    r_steps = []
    for ts in steps:

        step_start = ts - interval
        step_end = ts

        try:
            idx_start = all_steps.index(step_start)
        except ValueError:
            print("Cannot retrieve data for interval ending at step:", ts, "h")
            raise

        try:
            idx_end = all_steps.index(step_end)
        except ValueError:
            print("Cannot retrieve step:", step_end, "h for interval ending at step:", ts, "h")
            raise

        r_steps.extend(all_steps[idx_start+1:idx_end+1])

    # print("r_steps=", r_steps)

    # remove duplicates and sort
    r_steps = sorted(list(set(r_steps)), key=int)

    # return as a string
    return "[" + ",".join([str(i) for i in r_steps]) + "]"


def main():
    
    # get arguments
    if len(sys.argv) < 8:
        print("Too few arguments = " + str(len(sys.argv)) + ". Minimum number of arguments is 8.")
        sys.exit(1)

    mode = sys.argv[1]
    if mode not in ("data", "macro", "python"):
        print("Incorrect first argument: " + mode + " Allowed values: \"data\",\"macro\" or \"python\"")
        sys.exit(1)

    layer_def_file = sys.argv[2]
    mars_def_file = sys.argv[3]
    script_file = sys.argv[4]
    request_file = sys.argv[5]
    layer_name = sys.argv[6]
    style_name = sys.argv[7]
    need_title = sys.argv[8]
    if need_title == "1":
        need_title = True
    else:
        need_title = False

    # Read json defs
    layer_def = load_json_layer(layer_def_file)
    mars_def = load_json_mars(mars_def_file)

    # -----------------------------------
    # Build macro code for MARS retrieval
    # -----------------------------------

    extra_mars_options = {}
    interval = ""

    # Read arguments for the mars request
    arguments = sys.argv
    for v in arguments[9:]:
        try:
            (key, val) = v.split('=')
        except ValueError:
            print("No key is defined in argument: ", v)
            raise

        # 'interval' is not a mars key. If it is defined we need to modify
        #  the steps so that a proper interval could be retrieved
        if key != 'interval':
            extra_mars_options[key] = val
        else:
            interval = val

    # Get MARS request from layer definition
    mars = mars_def[layer_name]['mars']

    # Update it with the extra options
    mars.update(extra_mars_options)

    if interval:
        steps = mars['step']
        modified_steps = steps_for_interval(mars['step'], int(interval), layer_name)
        if modified_steps:
            mars['step'] = modified_steps
        else:
            print("Could not define steps for the specified interval=", interval)
            sys.exit(1)

    # print("name=", layer_name)
    # print("title=", type(layer_def))
    # print("mars=", mars)

    # -----------------------------------
    # Find out title and style
    # -----------------------------------

    # Get layer title
    layer_title = layer_def[layer_name]['title']

    # Get parameter shortName
    short_name = mars_def[layer_name]['shortName']

    # Get parameter post-processing option
    pproc_func = mars_def[layer_name].get('proc', "")

    # for certain layers we need to add extra parameters to the post processing
    # script
    pproc_func_extra_args = []

    if interval:
        pproc_func_extra_args.append(steps)
        pproc_func_extra_args.append(interval)

    # Get default style name if style is not defined
    if style_name == "":
        style_name = layer_def[layer_name]['style']

    # -----------------------------------
    # In data mode:
    # -generate macro to retrieve data
    # -define the title, contouring and legend as Metview requests
    # -----------------------------------

    if mode == "data":

        # -----------------------------------
        # Macro code to retrieve the data
        # -----------------------------------

        macro_text = "#Metview macro\n\n" \
                + "args=arguments()\n" \
                + "print(args)\n" \
                + "outputFile=args[1]\n" \
                + "data = " + build_mars_script(mars, "macro") + "\n\n"

        if pproc_func:
            macro_text += "data = " + build_pproc_script_call(mars, pproc_func, short_name, pproc_func_extra_args, "macro") + "\n\n"

        macro_text += "write(outputFile,data)\n\n" \
                + "return(0)"

        if pproc_func:
            macro_text += "\n\n" + build_pproc_script_code(pproc_func, "macro")

        req_text = ''

        # --------------------------------
        # Build title request
        # --------------------------------
        if need_title:
            req_text += build_title_request(layer_title, short_name)

        # --------------------------------
        # Build visdef request
        # --------------------------------

        req_text += "\n\n" + build_visdef_request(style_name)

        # --------------------------------
        # Build legend request
        # --------------------------------

        req_text += "\n\n" + build_legend_request() + "\n"

        # --------------------------------
        # Save request into file
        # --------------------------------
        # print(req_text)

        with open(request_file, 'w') as fp:
            fp.write(req_text)

        # -----------------------
        #  Save macro into file
        # -----------------------
        # print(macro_text)

        with open(script_file, 'w') as fp:
            fp.write(macro_text)

    # -----------------------------------------------------------------------------
    # In macro or python mode mode generate script to retrieve and plot the data
    # -----------------------------------------------------------------------------

    else:

        if mode == "macro" :
            script_text = "# Metview Macro\n\n"
        else:
            script_text = "import metview as mv\n\n"

        # --------------------------------
        #  Add licence text
        # --------------------------------

        with open(os.environ["METVIEW_DIR_SHARE"] + "/etc/licence_for_macros.txt", 'r') as fp:
            licence_text = fp.read().replace("[YEAR]", str(datetime.datetime.now().year))
            for s in licence_text.split("\n"):
                script_text += "# " + s + "\n"

        # -------------------------------------
        # Build post-processing code - Python
        # -------------------------------------

        if mode == "python" and pproc_func:
            script_text += "\n# The post-processing function\n" + build_pproc_script_code(pproc_func, mode) + "\n\n"

        # --------------------------------
        # Build mars retrieval
        # --------------------------------

        script_text += "\n# Retrieve data from MARS\ndata = " + build_mars_script(mars, mode) + "\n\n"

        # --------------------------------
        # Build post-processing call
        # --------------------------------

        if pproc_func:
            script_text += "# Perform post-processing on data\ndata = " \
                    + build_pproc_script_call(mars, pproc_func, short_name, pproc_func_extra_args, mode) + "\n\n"

        # --------------------------------
        # Build title
        # --------------------------------
        if need_title:
            script_text += "# Define title\ntitle = " + build_title_script(layer_title, short_name, mode) + "\n\n"

        # --------------------------------
        # Build visdef
        # --------------------------------

        script_text += "# Define contouring\ncont = " + build_visdef_script(style_name, mode) + "\n\n"

        # --------------------------------
        # Add legend
        # --------------------------------

        script_text += "# Define legend\nlegend = " + build_legend_script(mode) + "\n\n"

        # ---------------------------------
        # Plot command
        # ---------------------------------

        script_text += "# Generate plot\n" + script_command_prefix[mode]
        if need_title:
            script_text += "plot(data, title, cont, legend)\n\n"
        else:
            script_text += "plot(data, cont, legend)\n\n"

        # -----------------------------------
        # Build post-processing code - Macro
        # -----------------------------------

        if mode == "macro" and pproc_func:
            script_text += "\n# The post-processing function\n" + build_pproc_script_code(pproc_func, mode) + "\n\n"

        # -----------------------
        #  Save macro into file
        # -----------------------

        with open(script_file, 'w') as fp:
            fp.write(script_text)


if __name__ == "__main__":    
    main()      



# -*- coding: utf-8 -*-
#/usr/bin/env python
# Program to read NEMO output temperature field file (netCDF3),
# Initial Requirements:
# 1) convert it to netcdf4 and write one output variable per file.
# 2) Output files should also pass CF checker + CMIP conventions (possibly OGC).
# 3) Mars attributes should be clearly identified 
# 4) time should be handled (forecast time, assimilation window etc)
#
# Modified program to alter the split level/time fields created from cdo on
# the output of convert_nemo_to_1_variable_all_levels_and_timesteps.py.
# these files are 1 field/level/timestep per netcdf4 file. Uses CDO because
# it already has the timestep/level splitting capability built in.
# Dependencies:
#    netCDF4 python module
#    nco tools (ncks,ncatted)

# It may be necessary to remove this dependency on nco/cdo by coding this functionality in a 
# (local) C program.
#
# K Marsh 23/9/15

from netCDF4 import Dataset
import glob
import subprocess
import getopt
import sys,os

def runcmd(run_cmd):
    print "in run cmd: ", run_cmd
    process_obj = subprocess.Popen(run_cmd, shell=True, stdout = subprocess.PIPE)
    output, err = process_obj.communicate()
    print "*** Running  command ***\n",
    print "output:", type(output)
    print output
    if err:
        print "Error:", err
    return
            
def main():
    """
    input files are stored in a list created by glob.glob()
    Process the filenames and split each file into 1 2 field per record,
    naming the output files accordingly. Also need to set the mars attributes
    explicitly to indicate these are single times and levels. 

    """
    options, remainder = getopt.getopt(sys.argv[1:],'c:')
    print options,remainder
    if len(options) ==0:
        print "Option required; Exiting"
        sys.exit()
    for opt, arg in options:
        print opt,arg
        if opt in ('-c'):
           cf_cfg_fname = arg
           print "Config file is ",cf_cfg_fname
        else:
            print "Config file required; Exiting"
            sys.exit()
    try:
        cfg_file=open(cf_cfg_fname,"r")
    except:
        print "File to process does not exit; Exiting"
        sys.exit()

    lines=cfg_file.readlines()
    for line in lines:
#        print line
        if line.startswith("#"): # comment line: 
            continue
        elif line.startswith("\'"): # "Env: " line
            option, value = line.split("=")
            o=option.strip()
            v=value.strip()
            os.environ[o] ="$"+o+":"+v            
        else:
            print line
            option, value = line.split("=")
            o=option.strip()
            v=value.strip()
            if o == "files_to_process":
                files_to_process=v
            elif o == "path_to_ncks":
                path_to_ncks=v
            elif o == "path_to_ncatted":
                 path_to_ncatted = v
            else:
                print "Unmatched option"
    cfg_file.close()
#
# Process the input file list; this assumes that these files have a regular structure
#

    try:
        fnames = glob.glob(files_to_process)
        print "Files are: ",fnames
    except:
       print "Error creating file name list; Exiting"   
       sys.exit()
    if len(fnames) == 0:
       print "File name list is empty; Exiting"
       sys.exit() 
    time_steps = []
    level_steps = []
    time_step_counter = 0
    level_step_counter = 0
    for fname in fnames:
        dsin = Dataset(fname)
        try:
            print fname
            print (os.path.isfile(fname))
            dsin = Dataset(fname)
        except:
            print "NetCDF file to process cannot be opened; Exiting"
#python            sys.exit()
        time_steps[:] = dsin.variables['time'][:]
        level_steps[:] = dsin.variables['deptht'][:]
        print "Time Steps ", time_steps
        print "Vertical Levels ", level_steps
        for time_step in range(len(time_steps)):
            time_step_counter = time_step_counter + 1
            print "time_steps[time_step]", time_steps[time_step]
            time = int(time_steps[time_step])/(60 * 60)
            for level_step in range(len(level_steps)):
                level_step_counter = level_step_counter + 1
                level = level_steps[level_step]
                print "output strings are: ", time, level_step
                temp_level_str = "_T" + str(time_step) + "_L" + str(level_step + 1) + ".nc"
                fname_out = (fname.replace("split_data", "split_data/split_nco")).replace(".nc", temp_level_str)
                print fname_out
                cmd = path_to_ncks + " -O -d time," + str(time_step) + " -d deptht," + str(level_step) + " " + fname+" " + fname_out
                print cmd 
                runcmd(cmd)
                cmd = path_to_ncatted +" -O -a mars_step,data,m,c," + str(time) + " " + fname_out
                print cmd
                runcmd(cmd)
                cmd = path_to_ncatted +" -O -a mars_levelist,data,m,c," + str(level_step+1) + " " + fname_out
                print cmd
                runcmd(cmd)
                cmd = path_to_ncatted + " -O -a valid_min,deptht,m,f," + str(level) + " " + fname_out
                print cmd
                runcmd(cmd)
                cmd = path_to_ncatted + " -O -a valid_max,deptht,m,f," + str(level) + " " + fname_out
                print cmd
                runcmd(cmd)
                cmd = path_to_ncks + " -4 "+fname_out+" "+fname_out+"4"
                runcmd(cmd)
#
# break out of processing loop if only want first 3 levels for testing
#
                if level_step_counter == 3: 
                    break
#
# break out of processing loop if only want first timestep for testing
#
            if time_step_counter == 1: 
                break

if __name__ == "__main__":
    main()







def compute_speed(params, data, target_shortname):
	
	uParam = params[0]
	vParam = params[1]
	
	u = mv.read(data=data, param=uParam)
	v = mv.read(data=data, param=vParam)
	res = mv.sqrt(u*u+v*v)
	
	return res.grib_set_string(["shortName", target_shortname])


#!/usr/bin/env python
"""
cf_checks.py
 Python script to run the cf-checker from the command line
 Only requires:
  1  location of area-type-table.xml
  2  location of standard-name-table.xml
  3  python netCDF4 module to be installed
  4  LD_LIBRARY_PATH to be set in local ENV *before* running script, i.e.:
 export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:"/usr/local/apps/udunits/2.1.21/LP64/lib"
  5 path of data directory 
  6 glob pattern to match

 Input : Configuration file  cf_checks.cfg (in same directory as script)
 Output: cf check output/err results to stdout
 to run: python cf_checks.py -c cf_checks.cfg

"""

import os
import glob
import subprocess
import getopt
import sys
from netCDF4 import Dataset

def check_standard_names(filename):
    """
    Function to test if the NetCDF variables actually have standard names set.
    The values given to these will be checked in the run_cf_checks function
    """
    print "**********************\n"
    print "File: %s" % filename
    print "Check for standard_name attribute attached to variables"
    print "\n**********************"
    fin = Dataset(filename,"r")
    var_list = []
    std_name_count = 0
    data_check = 0
    for v_name, varin in fin.variables.iteritems():
        var_list.append(str(v_name))
        if "standard_name" in varin.ncattrs():
            print v_name, " variable -OK: has standard_name attribute set"
            std_name_count = std_name_count +1
            if v_name == "data":
                data_check = 1
        else:
            print v_name, " variable -ERROR: has NO standard_name attribute set"
    fin.close()
    print "**********************\n"
    print "Summary for %s :\n" % filename
    print "%d of %d variables have standard_name attribute set" % \
    (std_name_count,len(var_list))
    if data_check == 0 :
        print "ERROR: 'data' variable has NO standard_name attribute" 
    print "\n**********************"

def run_cf_checks(flist_in, cf_cmd):
    """
    check that variables have standard_name attributes and then
    run actual CF checks using the local version of the CF checker on the
    filelist created by the glob command
    """
    for fname in flist_in:
        check_standard_names(fname)
        print cf_cmd+fname
        process_out = subprocess.Popen(cf_cmd+fname, shell=True, \
        stdout=subprocess.PIPE)
        output, err = process_out.communicate()
        print "*** Running  CF checks command ***\n"
        if err:
            
            print "Error in running checks :", err

        for line in output.splitlines():
            print line
            if "CHECKING NetCDF FILE:" in line:
                print line

def main():
    """
    Set up the input file paths and environment ariables to allow the
    CF checker to run from the command line

    These are held by objects containing :
         hardcoded path to data directory
         glob pattern to generate list of files
         path to cfcheck script, 
         path to local copy of area type table,
         path to local copy of standard name table,
         CF version to check against
    """
    options, remainder = getopt.getopt(sys.argv[1:],'c:')
    print options,remainder
    if len(options) ==0:
        print "Option required; Exiting"
        sys.exit()
    for opt, arg in options:
        print opt,arg
        if opt in ('-c'):
           cf_cfg_fname = arg
           print "Config file is ",cf_cfg_fname
        else:
            print "Config file required; Exiting"
            sys.exit()
    cfg_file=open(cf_cfg_fname,"r")
    lines=cfg_file.readlines()
    for line in lines:
#        print line
        if line.startswith("#"): # comment line: 
            continue
        elif line.startswith("\'"): # "Env: " line
            option, value = line.split("=")
            o=option.strip()
            v=value.strip()
            os.environ[o] ="$"+o+":"+v            
        else:
            print line
            option, value = line.split("=")
            o=option.strip()
            v=value.strip()
            if o == "data_dir":
               print "data Dir match"
               data_dir=v
               print data_dir
            elif o == "glob_pattern":
                glob_pattern=v
            elif o == "path_to_cfchecks":
                path_to_cfchecks=v
            elif o == "path_to_area_table":
                 path_to_area_table = v
            elif o == "path_to_standard_name_table":
                 path_to_standard_name_table = v
            elif o == "cf_version":
                cf_version = v
            else:
                print "Unmatched option"
    cfg_file.close()

    print data_dir, glob_pattern
    full_glob=data_dir + glob_pattern
    print full_glob
    flist = glob.glob(data_dir + glob_pattern)
    print "files to CF check are: \n", flist
    print path_to_cfchecks,path_to_area_table,path_to_standard_name_table
    print cf_version
    cf_cmd_root = path_to_cfchecks+" -a " + path_to_area_table + " -s " +\
                  path_to_standard_name_table+" -v "+cf_version+" "
    print cf_cmd_root
    run_cf_checks(flist, cf_cmd_root)

if __name__ == "__main__":
    main()





#!/usr/bin/env python
#
# -*- coding: utf-8 -*-
# Program to read NEMO ocean model output temperature field file (netCDF3),
# Requirements:
# 1) Convert it to netcdf4 and write one output variable per file.
# 2) Output files should also pass CF checker.
# 3) Mars attributes should be added clearly identified 
# 4) Modifications to time should be handled 
# 
# K Marsh 20/7/16
#
#*****************************************************************
# /convert_nemo_to_1_variable_all_levels_and_timesteps.py -c convert_nemo_to_1_variable_all_levels_and_timesteps.cfg
#
#
from netCDF4 import Dataset,netcdftime,num2date
import glob
import sys
import getopt
import datetime
import sys

def process_config_file(cfg_file_in):
    lDebugFlag = False
    lines = cfg_file_in.readlines()
    mars_dict = {}
    at_dict = {}
    var_dict = {}
    fnames = []
    op_dir=""
    for line in lines:
        if line.startswith("#") or len(line.strip()) == 0 : # comment/empty lines: 
            continue  
        elif line.startswith("\'"): # "Env: " line
            option, value = line.split("=")
            o=option.strip()
            v=value.strip()
            os.environ[o] ="$"+o+":"+v            
        else:
            if lDebugFlag:
                print line
            option, value = line.split("=")
            o=option.strip()
            v=value.strip()
            if o == "db_name":
                db_name = v
            elif o == "host_name":
                host_name = v
            elif o == "user_name":
                 user_name = v
            elif o == "pass_name":
                pass_name =v
            elif o == "mars_type":
                 mars_dict["mars_type"] = v                 
            elif o == "mars_class":
                mars_dict["mars_class"] = v
            elif o == "mars_stream":
                 mars_dict["mars_stream"] = v
            elif o == "mars_expver":
                mars_dict["mars_expver"] =v
            elif o == "mars_date":
                 mars_dict["mars_date"] = v                  
            elif o == "mars_time":
                mars_dict["mars_time"] = v
            elif o == "mars_step":
                 mars_dict["mars_step"] = v
            elif o == "mars_number":
                mars_dict["mars_number"] =v
            elif o == "mars_levelist":
                 mars_dict["mars_levelist"] = v   
            elif o == "mars_levtype":
                mars_dict["mars_levtype"] = v
            elif o == "mars_param":
                 mars_dict["mars_param"] = v
            elif o == "fnames":
                fnames.append(v)
            elif o == "input_dir":
                fnames = glob.glob(v+"\/*.nc")
            elif o == "output_dir": 
                op_dir = v
            elif o == "global_attributes_Conventions":
                 at_dict["Conventions"] = v              
            elif o == "global_attributes_title":
                 at_dict["title"] = v      
            elif o == "global_attributes_institution":
                 at_dict["institution"] = v      
            elif o == "global_attributes_references":
                 at_dict["references"] = v      
            elif o == "global_attributes_source":
                 at_dict["source"] = v  
            elif o == "global_attributes_history":
                 at_dict["history"] = v      
            elif o == "global_attributes_comment":
                 at_dict["comment"] = v                                                      
            elif o == "nemo_var_name":
                 var_dict[v.split(":")[0]]= [v.split(":")[1],v.split(":")[2],v.split(":")[3]]
            else:
                print "Warning: Unmatched option", o
    cfg_file_in.close()
    
    if len(fnames) == 0:
        print "No files to process: exiting"
        sys.exit()
    if op_dir == "":
        print "No output directory specified: exiting"
        sys.exit()      
    if not op_dir.endswith("\/"):
        op_dir =op_dir + "/"
          
    if len(mars_dict) != 11:
        print "Missing Mars elements: exiting"
        sys.exit()
    if lDebugFlag:
        print "MARS dictionary is :", mars_dict
    return fnames, at_dict, mars_dict, var_dict, op_dir


def get_original_dimensions_and_global_attributes(file_in):
#
#get dimensions
#
    dim_list = file_in.dimensions
    dim_dict={}
#
#Copy dimensions from whole file
#
    for dname, the_dim in file_in.dimensions.iteritems():
        dim_dict[dname] = len(the_dim)
#
# get global attributes 
#
    nc_attrs = file_in.ncattrs()
    print nc_attrs
    print "NetCDF Global Attributes:"
    if len(nc_attrs) == 0:
        print "None"
    for nc_attr in nc_attrs:
         print nc_attr           
    return dim_dict, nc_attrs
#   
# change existing variable attributes -form a dictionary to hold the ones to be used
#

def modify_variable_attributes(var_in):
    lDebugFlag1 = True
    lDebugFlag1 = False
    var_atts_out = {}
    var_atts_to_skip=["title",]
    for ncattr in var_in.ncattrs():    
        if "standard_name" in ncattr:
            var_atts_out["NEMO_standard_name"] = var_in.getncattr(ncattr)
            continue
        if ncattr == "_FillValue":
            f_val = getattr(var_in, "_FillValue")
            var_atts_out[ncattr] = f_val
            continue
        if ncattr == "title": 
            continue
        if lDebugFlag1:
            print ncattr       
            print var_in.getncattr(ncattr)
        var_atts_out[ncattr] = var_in.getncattr(ncattr)    
    if lDebugFlag1:
        print "variable attributes" , var_atts_out
    return var_atts_out
        
def add_mars_atts(fid, att_dict, var):

    for item_att in att_dict.keys():
        print item_att
#
#  need to skip mars_param attribute for cases when no mapping?
#             
        print item_att, type(item_att)
        print att_dict[item_att], type(att_dict[item_att]) 
        if item_att in ["mars_levelist"]:
           fid.variables[var].setncattr(item_att, float(att_dict[item_att]))
        elif item_att in ["mars_number","mars_time","mars_expver","mars_date"]:
            fid.variables[var].setncattr(item_att, int(att_dict[item_att]))
        else:
            fid.variables[var].setncattr(item_att, att_dict[item_att])
    return        

#
# need to adjust the reference time to that specified in filename
#

def adjust_time(fname_in,time_units_orig):
   lDebugFlag = False
   filename_time = (fname_in.split("/")[-1]).split("_")
   time1 = filename_time[2][-2:]
   time2 = filename_time[3][-2:]
   print time1,time2
   if time1 == time2 :
       time_units_parts = []
       time_units_parts = time_units_orig.split()
       time_units_parts[-1] = time1 + ":00:00" 
       time_units_new = " ".join(time_units_parts)
       if lDebugFlag:
           print time_units_new
   else: 
       print "times in filenames do not match: exit"
       sys.exit(1)
   return time_units_new
        
def main():
    lDebugFlag = False
    print "to run: convert_nemo_to_1_variable_all_levels_one_timestep.py -c <config file>"
    print "e.g. convert_nemo_to_1_variable_all_levels_one_timestep.py -c convert_nemo_to_1_variable_all_levels_one_timesteps.cfg"
    print "Parsing input config file"
    options, remainder = getopt.getopt(sys.argv[1:],'c:')
    if len(options) == 0:
        print "Option required; Exiting"
        sys.exit()
    for opt, arg in options:
        print opt,arg
        if opt in ('-c'):
           cf_cfg_fname = arg
           print "Config file is ",cf_cfg_fname
        else:
            print "Config file required; Exiting"
            sys.exit()
    try:
        cfg_file=open(cf_cfg_fname,"r")
    except:
        print "File to process does not exit; Exiting"
        sys.exit()
    
#  Initialise variables to hold file information

    files = []
    at_cfg_dict = {}
    mars_cfg_dict = {}
    var_cfg_dict = {}
    start_date = ""
    start_time = ""
    
    files, at_cfg_dict, mars_cfg_dict, var_cfg_dict, output_dir = process_config_file(cfg_file)
 
    if lDebugFlag:
        print "at_cfg_dict", at_cfg_dict 
        print mars_cfg_dict 
        print var_cfg_dict
        print files
        print "files to process: "
        print files,
        print "\n"
    
#    files = ["/hugetmp/cera20c/split/2366_1d_1900022721_1900022821_grid_T_02.nc",] # dummy for testing
    
    if len(files) == 0:
       print "No files to process - exiting "
       sys.exit()

    for fname in files:
        fin=Dataset(fname,'r')
        file_dims, file_atts = get_original_dimensions_and_global_attributes(fin)
        print "Input file Dimensions: ",file_dims
        print "Input file global attributes: ", file_atts

# get list of variables

        fin_var_list = []
        for v in fin.variables:
            if lDebugFlag:
                print v
            fin_var_list.append(v)

        print fin_var_list
        var_count = 0
        for vname in fin_var_list:

# loop through variables

####            if vname == "votemper":  #temp var to select -use below in operations

            if vname in var_cfg_dict.keys():
                print "match for ", vname 
                var=fin.variables[vname]

# get variable attributes

                var_atts={k: var.getncattr(k) for k in var.ncattrs()}
                if lDebugFlag:
                    print "Variable attributes",
                    print var_atts
                    print "Variable Dimensions"
                    print var.dimensions, len(var.dimensions)
                for i in range(len(var.dimensions)):
                    if lDebugFlag:
                        print type(var.dimensions[i])
                        print i, var.dimensions[i]
                    if "time" in str(var.dimensions[i]):
                        time_index = i
                        time_length = var.shape[i]
                        if lDebugFlag:
                            print "Variable shape is ",var.shape
                            print "Variable time match at index:", i
                            print time_length
                            print "Variable coordinates"
                            print var.coordinates
                            print var.coordinates.split()[i]
                        if "time" in var.coordinates.split()[i]:
                            time_values = fin.variables[var.coordinates.split()[i]]
                            if lDebugFlag: 
                                print "time in coordinates at correct position"
                                print time_values[:]

# if timestep >1 loop through timesteps
# get timestep assuming time dimension is the first/second  dimension element

                        for time_step in range(time_length):
                            if time_index == 0:
                                var_time_step=var[time_step:time_step+1,...]

                            if time_index == 1:
                                var_time_step=var[:,time_step:time_step+1,...]            
                            time_step_value=fin.variables['time_counter'][time_step]        
                            if lDebugFlag: 
                                print "/nVariable: time step value", time_step_value
                                print "/nVariable: shape is ", var_time_step.shape

# get var coordinates, attributes 

                            if lDebugFlag: 
                                print "\noutput variable dimensions:"
                                print var.dimensions,var_time_step.shape
                            var_time_step_dimensions={}
                            for i in range(len(var.dimensions)):
                                var_time_step_dimensions[var.dimensions[i]]=var_time_step.shape[i]
                            if lDebugFlag: 
                                print var_time_step_dimensions    
                                print "\noutput variable attributes"
                                print var_atts
                                print "\noutput variable coordinate variables"
                                print var.coordinates
                                print "\noutput variable coordinate attribute variables:"
                            if lDebugFlag: 
                                for att in var_atts.keys():
                                    print att
                                    print var_atts["coordinates"]     

# open output file          fname_out used for testing, fname_out1 from config file

                            fname_out1 = output_dir + "nemo_" + (fname.split("/")[-1]).split(".")[0] + "_" + vname + "_timestep_" + str(time_step) + ".nc"
                            print "extended filename:", fname_out1
                            fname_out = "../nemo_split_test/test_split_" + str(time_step) + "_" + vname + ".nc"
                            print "writing to "+ fname_out1
                            try:
                               dsout = Dataset(fname_out1, "w", format = "NETCDF4_CLASSIC") #"NETCDF3_CLASSIC")
                            except:
                                print "Error creating output file ", fname_out
                                print "exiting"
                                sys.exit()

#create dimensions

                            if lDebugFlag:
                                print var.shape
                                print var_time_step_dimensions
                            for dname, the_dim in var_time_step_dimensions.items():
                               if dname == "time_counter":
                                   dname = "time"
                               if lDebugFlag:
                                   print "creating dimension", dname, the_dim
                               if dname == "time":
                                   dsout.createDimension(dname, size = 0)
                               else:
                                   dsout.createDimension(dname, the_dim) 

# create bounds

                            for dname, the_dim in file_dims.items():
                               if dname == "tbnds":
                                   dsout.createDimension(dname,the_dim)
                            
#get list of all required coordinate variables -from variable itself and coordinate attribute
     
                            all_coords_list=[]
                            bounds_list=[]
                            for v in var.coordinates.split():
                                all_coords_list.append(v)

                            for att in var_atts.keys():

                                if att == "coordinates":
                                    if lDebugFlag:
                                        print "variable coord atts:", 
                                    for item in var_atts["coordinates"].split():
                                        if item in all_coords_list:
                                            if lDebugFlag:
                                                print item, "already in coordinate list"
                                            continue
                                        else:
                                            if lDebugFlag:
                                                print item, "to be appended"
                                            all_coords_list.append(item)                                                             

                            if lDebugFlag:
                                print all_coords_list,len(all_coords_list)

# write out coordinate variable and attributes; amend name of time coordinate

                            for v_coord in all_coords_list:
                                var_coord = fin.variables[v_coord]
                                var_coord_time_dim =[]
                                for dim in var_coord.dimensions:
                                    if "time_counter" in dim:
                                        dim = "time"
                                    var_coord_time_dim.append(dim)
                                  
                                if v_coord == "time_counter":
                                    v_coord_time = "time"                                    
                                    out_var = dsout.createVariable(v_coord_time,var_coord.dtype, var_coord_time_dim)
                                else:
                                    out_var = dsout.createVariable(v_coord,var_coord.dtype, var_coord_time_dim)
                                if lDebugFlag:
                                    print v_coord,var_coord.dtype, var_coord.dimensions
                                    print type(out_var)

                                if "time" in v_coord:
                                    if lDebugFlag:
                                        print "tstep ***", time_step_value
                                    dtime = num2date(time_step_value,var_coord.units)
                                    out_var[:]=time_step_value
                                else:
                                    out_var[:] = var_coord[:]
                                if lDebugFlag:
                                    print "var_coord attributes: ",var_coord.ncattrs()

                                for ncattr in var_coord.ncattrs():
                                    if ncattr == "_FillValue":  
                                        f_val = getattr(var_coord, "_FillValue")
                                        out_var.setncattr(ncattr, fval) 

                                    if ncattr == "title": 
                                        continue

# Check for bounds variable **** need to get correct value ******

                                    if ncattr == "bounds":
                                        if lDebugFlag:
                                            print "bounds att for ", var_coord.getncattr(ncattr)
   
                                        bounds_list.append(var_coord.getncattr(ncattr)) 
                                                                                                   
#
# Setting attributes for required co-ordinate variable attribute: 
#
#                                    print dir(out_var),type(out_var)

                                    if v_coord == "time_counter" and var_coord.getncattr(ncattr) == "time_counter_bnds":
                                        print "var_coord.getncattr(ncattr)",var_coord.getncattr(ncattr)
                                        out_var.setncattr(ncattr, "time_bounds")
                                    elif v_coord == "time_counter" and ncattr == "units":
                                        time_units = var_coord.getncattr(ncattr)
                                        print time_units
                                        new_time_units=adjust_time(fname,time_units)
                                        out_var.setncattr(ncattr, new_time_units)
                                    else:    
                                        out_var.setncattr(ncattr, var_coord.getncattr(ncattr))                            

# adjust time to allow for non-uniform NEMO data start

# write bounds variable to output file

                            if lDebugFlag: 
                                print "bounds list", bounds_list
                            for bvar in bounds_list:
                                bound_var=fin.variables[bvar]
                            bound_var_time_dim=[]
                            for dim in bound_var.dimensions:
                                if dim == 'time_counter':
                                    dim = "time"
                                bound_var_time_dim.append(dim)
                            if lDebugFlag:
                               print "bounds"
                               print "bound_var ", bound_var
                               print "bound_var_dtype ",bound_var.dtype
                               print "bound_var_dimensions ", bound_var_time_dim
                               print "bound_var_ncattrs ", bound_var.ncattrs()
                            out_var = dsout.createVariable("time_bounds",bound_var.dtype, bound_var_time_dim)
                            out_var[:] = bound_var[:]
                            for ncattr in bound_var.ncattrs():
                                out_var.setncattr(ncattr, bound_var.getncattr(ncattr))                           
                            if lDebugFlag:
                                print dir(var_time_step),type(var_time_step)
                                print vname,var_time_step.dtype,var.dimensions
                            var_time_dim=[]
                            for dim in var.dimensions:
                                if dim == 'time_counter':
                                    dim = "time"
                                var_time_dim.append(dim)
                                                        
# write variable data        

                            if ncattr == "_FillValue":
                                f_val = getattr(varin, "_FillValue")
                                out_var = dsout.createVariable(vname,var_time_step.dtype, var_time_dim, fill_value = f_val)
                            else:
                                out_var = dsout.createVariable(vname,var_time_step.dtype, var_time_dim)
                            out_var[:] = var_time_step[:]
                                
# write variable attributes

                            var_att_list = modify_variable_attributes(var)

# Amend units string if required

                            if vname == "votemper":
                                if var_att_list["units"] == "C":
                                    var_att_list["units"] = "degC"
                            if vname == "sosaflx":
                                if var_att_list["units"] == "Kg/m2/s":
                                    var_att_list["units"] = "Kg/m^2/s"
                            if vname == "soicecov":
                                if var_att_list["units"] == "[0,1]":
                                    var_att_list["units"] = "1"

                            if vname == "soicealb":
                                if var_att_list["units"] == "[0,1]":
                                    var_att_list["units"] = "1"

                            if vname == "sowafldp":
                                if var_att_list["units"] == "Kg/m2/s":
                                    var_att_list["units"] = "Kg m-2 s-1"

                            if vname == "sowaflup":
                                if var_att_list["units"] == "Kg/m2/s":
                                    var_att_list["units"] = "Kg m-2 s-1"

                            if vname == "sosaflup":
                                if var_att_list["units"] == "Kg/m2/s":
                                    var_att_list["units"] = "Kg m-2 s-1"

# write MARS specific attributes amending elements fo thos calculated from file

                            cdftime=netcdftime.utime(dsout.variables["time"].units)
                            start_date_time=str(cdftime.num2date(float(dsout.variables["time_bounds"][0][0]))).split()
                            m_date=start_date_time[0].replace("-","")
                            m_time="".join(start_date_time[1].split(":")[:-1])
                            mars_cfg_dict["mars_date"] = m_date
                            mars_cfg_dict["mars_time"] = m_time

# need to adjust mars_level and levelist as required
                            #mars_cfg_dict["mars_level"] = ""
                            #mars_cfg_dict["mars_levelist"] =""                        

                            add_mars_atts(dsout, mars_cfg_dict, vname)
                            
                            for v in var_att_list:    
                                if lDebugFlag:
                                    print "* ",v, var_att_list[v]
                                if v == "_FillValue":
                                    continue
                                if v == "coordinates":
                                
                                    out_var.setncattr(v, var_att_list[v].replace("time_counter","time"))
                                else:
                                    out_var.setncattr(v, var_att_list[v])

                            cf_name=var_cfg_dict[vname][0]
                            print "CF Name is ",cf_name
                            out_var.setncattr("standard_name",cf_name)
                            out_var.setncattr("NEMO_variable_name",vname)

#write global attributes
                            if lDebugFlag:
                                print len(file_atts)
                            if len(file_atts) > 0:
                               for ncattr in file_atts:
                                   if ncattr == "history":
                                      continue
                                   dsout.setncattr(ncattr, file_atts[ncattr])

# write global attributes from config file

                            for key in at_cfg_dict:
                                dsout.setncattr(key, at_cfg_dict[key])   
                            
                            var_count = var_count + 1     
                                   
# close output file 
                            dsout.close()

#close input file 

        fin.close()
        
        print "Processed: " , fname 
        print "No. of Variables in file: " , len(fin_var_list)
        print "No. of Variables processed: ", var_count 
    
    
    
if __name__ == "__main__":
    main()




#!/usr/bin/env python3
#
# (C) Copyright 1996- ECMWF.
#
# This software is licensed under the terms of the Apache Licence Version 2.0
# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
#
# In applying this licence, ECMWF does not waive the privileges and immunities
# granted to it by virtue of its status as an intergovernmental organisation nor
# does it submit to any jurisdiction.

from mpl_toolkits.basemap import Basemap
import matplotlib.pyplot as plt
import sys

lats = []
lons = []
with open(sys.argv[1]) as f:
    for line in f:
        x = line.split(" ")
        lats.append(float(x[0]))
        lons.append(float(x[1]))


north = max(lats)
south = min(lats)
east = max(lons)
west = min(lons)

print(north, west, south, east)

map = Basemap(projection="cyl", lat_0=(north + south) / 2.0, lon_0=(west + east) / 2.0)
# # resolution = 'h', area_thresh = 0.1,
# llcrnrlon=west, llcrnrlat=south,
# urcrnrlon=east, urcrnrlat=north)

map.drawcoastlines()
map.drawcountries()
map.fillcontinents(color="coral")
map.drawmapboundary()

x, y = map(lons, lats)
map.plot(x, y, "bo", markersize=0.1)

plt.show()



def compute_maximum(params, data, target_shortname, interval_steps, interval):

    if len(params) == 0 or len(data) == 0 :
        return None

    param = params[0]
    fs = mv.read(data = data, param = param)

    if len(fs) == 0 :
        return None
   
    # get the steps from the input fieldse
    steps = mv.grib_get_long(fs, "step")
    if not isinstance(steps, list):
        steps = [steps]
        
    # initialise result
    res = mv.Fieldset()

    # loop for the required interval steps
    for ts in interval_steps:

        # define start and end step for interval
        step_start = ts - interval + 1
        step_end = ts

        # collect fields in the given interval. We go in reverse order
		# so that the first field collected should be valid at the end
		# of the interval. 
        f = mv.Fieldset()
        for i in range(len(fs)-1,-1,-1):
            if steps[i] in range(step_start, step_end+1):
                f.append(fs[i])

        # compute the maximum for the given interval. The metadata (step etc.)
        # will be copied from the first field of fieldset f!
        if f:
            res.append(mv.max(f))
        else:
            return None

    # set correct shortname for result
    res = mv.grib_set_string(res, ["shortName", target_shortname])

    # mark as non-derived field - so that the correct scaling could be applied in contouring
    res = mv.grib_set_long(res, ["generatingProcessIdentifier", 149])
    
    return res


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# -*- coding: utf-8 -*-
# Program to read NEMO ocean model output temperature field file (netCDF3),
# Requirements:
# 1) Convert it to netcdf4 and write one output variable per file.
# 2) Output files should also pass CF checker.
# 3) Mars attributes should be added clearly identified
# 4) Modifications to time should be handled
#
# K Marsh 20/7/16
#
# 
# v3 modified from V2 to take command line input file, output file (prefix),
# type of file to be processed and configuration file to amend attributes etc.
#
# Currently only works for NEMO 3hr and 1D data files - Not 1 month/ non-NEMO data
#
# K Marsh 8/8/16
#
#*****************************************************************
# to run:
# python convert_nemo_to_1_variable_all_levels_one_timestep_v2.py 
# -i copy_of_2366_1d_1900022721_1900022821_grid_T_02.nc 
# -o copy_of_2366_1d_1900022721_1900022821_grid_T_02 
# -k NEMO -c convert_nemo_to_1_variable_all_levels_one_timestep.cfg
# 
# Note that this appends the variable name, timestep and "INTERIM.nc3" 
# to the output filename
#
from netCDF4 import Dataset, netcdftime, num2date
import glob
import sys
import getopt
import datetime
import os
import calendar

def seconds_in_month(month, year):
    nomatter, daysinmonth = calendar.monthrange(year, month)
    return daysinmonth * 24 * 60 * 60


def get_original_dimensions_and_global_attributes(file_in):
    islDebugFlag0 = True
#
#get dimensions
#
    dim_list = file_in.dimensions
    dim_dict = {}
    nc_attrs = {}
#
#Copy dimensions from whole file
#
    for dname, the_dim in file_in.dimensions.iteritems():
        dim_dict[dname] = len(the_dim)
#
# get global attributes
#
    nc_atts = file_in.ncattrs()
    print nc_atts, type(nc_atts)
    print "NetCDF Global Attributes:"
    print dir(file_in)
    if len(nc_atts) == 0:
        print "No Global attributes in source file"
    if islDebugFlag0:
        for nc_attr in nc_atts:
            print nc_attr
            nc_attrs[nc_attr] = file_in.getncattr(nc_attr)
    return dim_dict, nc_attrs


print "to run: "
print "split monthly nemo data file to extract 1 variable (salinity) " +\
"-i <input file> -o <output file prefix> "
print "to Run "
print "python split_monthly.py "
print "-i <nemo monthly file>" 
print "-o <nemo monthly split file> "


print "Note that this appends the variable name, timestep and <INTERIM.nc3>" 
print "to the output filename"

print "Parsing input config file"
options, remainder = getopt.getopt(sys.argv[1:], 'c:i:o:k:')
print options, remainder
if len(options) == 0:
    print "Option required; Exiting"
    sys.exit()
for opt, arg in options:
    print opt, arg

    if opt == '-i':
        input_filename = arg
        if not os.path.isfile(input_filename):
            print "Input file does not exist; exiting"
            sys.exit()
        print "Input file is ", input_filename   
        hasInputFile = True         
    if opt == '-o':   
        output_filename = arg
        if os.path.isfile(output_filename):
            print "Output file does exist and will be overwritten"
        print "Output file is ", output_filename            
        hasOutputFilePath = True



fname_out_temp = output_filename
fname = input_filename

#flist = glob.glob("/hugetmp/cera20c/model_data/2366_1m_1900*.nc")
#print flist

islDebugFlag = 0

#cmd = "rm -f /hugetmp/cera20c/model_data/split_month/*.nc*"
#os.system(cmd)

#op_dir = "/hugetmp/cera20c/model_data/split_month/"

co_var = "vosaline"

for var_count in [1]:
       fin = Dataset(fname, 'r')
     
       #fname_out_temp = op_dir + co_var + "_" + fname.split("/")[-1] + "4"
       
       print "writing INTERIM NC4 file to " + fname_out_temp

       try:
          dsout = Dataset(fname_out_temp, "w", \
          format="NETCDF4_CLASSIC")
       except:
          print "Error creating output file ", fname_out_temp
          print "exiting"
          sys.exit()
       date_str = fname.split("/")[-1].split("_")[2]
#       print "**",date_str

       year=date_str[0:4]
       month= date_str[4:6]
       day=date_str[6:9].lstrip("0")
       print year, month,day
       time_units_str = "seconds since " + year +"-"+ month+"-"+ date_str[6:9] +" 00:00:00"
       print time_units_str       
       

       var_out_dimensions = {}
       var_out = fin.variables[co_var] 

#       print var_out.shape
#       print var_out
#       print "dimesniosns", var_out.dimensions


# set dimensions

       dim_count = 0

       for dim_name in var_out.dimensions:
           if dim_name == "time_counter":
               var_out_dimensions["time"] = var_out.shape[dim_count]
           elif dim_name == "deptht":
               var_out_dimensions["depth"] = var_out.shape[dim_count]
           else:    
               var_out_dimensions[dim_name] = var_out.shape[dim_count]
           dim_count = dim_count + 1
           print dim_name, var_out_dimensions
       if islDebugFlag:
           print var_out_dimensions
           print var_out.shape
           print type(var_out), type(var_out)
       
       print var_out_dimensions
       print fin.variables[co_var].datatype
       print 'dimensions',var_out_dimensions
       for dname, the_dim in var_out_dimensions.iteritems():
           if dname == "time_counter":
               dsout.createDimension(dname, size=0)
           else:
               dsout.createDimension(dname, the_dim)    

# get time values from bounds

       intyear=int(year)
       intmonth=int(month)
       secs=seconds_in_month(intmonth, intyear)
       
       time_set = 0
       lower_time_bound = 0
       upper_time_bound = secs
       
#       dstime_bounds'][0,0] = 0
#       dset.variables['time_bounds'][0,1] = secs 
               
# create variable
   
       outVar = dsout.createVariable(co_var, \
       fin.variables[co_var].datatype, \
       ("time", "depth", "y", "x"))

      
       for k in fin.variables[co_var].ncattrs():
           print k
           if k == "coordinates": 
              print "reset coords *****",k, type(fin.variables[co_var].getncattr(k)), 
              print type("time depth nav_lat nav_lon") 
              co_str = "time depth nav_lat nav_lon"
              outVar.setncattr("coordinates",co_str)
           else: 
               outVar.setncattr(k,fin.variables[co_var].getncattr(k))
           
       outVar[:] = fin.variables[co_var][:] 
       
# add extra attributes
       ec_var_atts = {"standard_name" : "sea_water_salinity", \
                "cell_methods":"time: mean (interval: 1.0 month)" , \
                "mars_stream" : "enda" , \
                "mars_class" : "ep" , \
                "mars_type" : "an" , \
                "mars_expver" : 2366 , \
                "mars_levtype" : "dp" , \
                "mars_time" : 0 , \
                "mars_date" : int(date_str) , \
                "mars_param" : 34 , \
                "mars_levelist" : 1 , \
                "mars_number" : 1 }
       
       for ncattr in ec_var_atts.keys():
           outVar.setncattr(ncattr, ec_var_atts[ncattr])        
       
          
# create time variable 
       
       outVar = dsout.createVariable("time", \
       fin.variables[co_var].datatype, \
       ("time",))
       
       for k in fin.variables["time_counter"].ncattrs():
           if k == "time_origin": 
               continue
           outVar.setncattr(k,fin.variables["time_counter"].getncattr(k))
           if k == "bounds": 
               outVar.setncattr(k,"time_bnds")  
           if k == "units":
               outVar.setncattr(k,time_units_str)  
                    

       outVar[:] = time_set

#       outVar[:] = fin.variables["time_counter"][:]        #for original values

# create depth variable
       
       outVar = dsout.createVariable("depth", \
       fin.variables["deptht"].datatype, \
       ("depth",))
       for k in fin.variables["deptht"].ncattrs():
           if k == "title": 
               outVar.setncattr("title","depth")
           else:
               outVar.setncattr(k,fin.variables["deptht"].getncattr(k))

       outVar[:] = fin.variables["deptht"][:]    

#nav lon
                 
       outVar = dsout.createVariable("nav_lon", \
       fin.variables["nav_lon"].datatype, \
       ("y","x"))
       outVar.setncatts({k: \
       fin.variables["nav_lon"].getncattr(k) \
       for k in fin.variables["nav_lon"].ncattrs()})

       outVar[:] = fin.variables["nav_lon"][:]                    

#nav lat
       
       outVar = dsout.createVariable("nav_lat", \
       fin.variables["nav_lat"].datatype, \
       ("y","x"))
       outVar.setncatts({k: \
       fin.variables["nav_lat"].getncattr(k) \
       for k in fin.variables["nav_lat"].ncattrs()})

       outVar[:] = fin.variables["nav_lat"][:]     

# time bounds

       tbnds_length = 2 
       dsout.createDimension("tbnds",tbnds_length )
       outVar = dsout.createVariable("time_bnds", \
       fin.variables["time_counter_bnds"].datatype, \
       ("time", "tbnds"))
       outVar.setncatts({k: \
       fin.variables["time_counter_bnds"].getncattr(k) \
       for k in fin.variables["time_counter_bnds"].ncattrs()})
       outVar[0,0] = lower_time_bound
       outVar[0,1] = upper_time_bound
       
#       outVar[:] = fin.variables["time_counter_bnds"][:] #for original values
       
       
       
# Global attributes       
       
#      
       nc_attrs_dict = {}
       nc_atts_list = fin.ncattrs()
       print nc_atts_list, type(nc_atts_list)
       print "NetCDF Global Attributes:"

       if len(nc_atts_list) == 0:
           print "No Global attributes in source file"

       for nc_attr in nc_atts_list:
           print nc_attr
           nc_attrs_dict[nc_attr] = fin.getncattr(nc_attr)       
       print nc_attrs_dict
           
           
       for ncattr in nc_attrs_dict.keys():
           if ncattr == "history" or ncattr == "nco_openmp_thread_number":
               continue
           print "***",ncattr, nc_attrs_dict[ncattr]
           dsout.setncattr(ncattr, nc_attrs_dict[ncattr])       

       ec_global_atts={"comment":"Produced at ECMWF",
       "title":"NEMO model output",
       "Conventions" : "CF-1.6",
       "source":"NEMO V3.4" ,
       "references": "Madec G. 2008: NEMO ocean engine Note du Pole de " + \
       "modélisation, Institut Pierre-Simon Laplace (IPSL), France, No 27 "+ \
       "ISSN No 1288-1619. \\nhttp://www.nemo-ocean.eu/content/download/21612/"+ \
       "97924/file/NEMO_book_3_4.pdf",
       "institution":"ECMWF"}
        
       for ncattr in ec_global_atts.keys():

           print "***",ncattr, ec_global_atts[ncattr]
           dsout.setncattr(ncattr, ec_global_atts[ncattr])       
        
       dsout.close()
     
       fin.close()



#!/usr/bin/env python

# (C) Copyright 1996-2015 ECMWF.

# This software is licensed under the terms of the Apache Licence Version 2.0
# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
# In applying this licence, ECMWF does not waive the privileges and immunities
# granted to it by virtue of its status as an intergovernmental organisation nor
# does it submit to any jurisdiction.

# Baudouin Raoult - ECMWF Jan 2015


# See http://unidata.github.io/netcdf4-python/netCDF4.Dataset-class.html

from netCDF4 import Dataset
import sys
import numpy

ERRORS = 0


def error(text):
    global ERRORS
    ERRORS += 1
    print "+    ERROR:", text


def mismatch(title, v1, v2):
    global ERRORS
    ERRORS += 1
    print "+ MISMATCH:", title
    print "      FILE:", sys.argv[1]
    print "     VALUE:", v1
    print "      FILE:", sys.argv[2]
    print "     VALUE:", v2


def compare_lists(what, l1, l2):
    s1 = set(l1)
    s2 = set(l2)

    if len(s1 - s2):
        error("%s [%s] only in %s" % (what, ",".join([str(x) for x in list(s1-s2)]), sys.argv[1]))
        return False

    if len(s2 - s1):
        error("%s [%s] only in %s" % (what, ",".join([str(x) for x in list(s2-s1)]), sys.argv[2]))
        return False

    return True


def compare_attributes(ns, name, a1, a2):

    if type(a1) != type(a2):
        mismatch("Type of attributes '%s:%s'" % (ns, name,), type(a1), type(a2))

    if a1 != a2:
        a1 = str(a1)
        a2 = str(a2)
        if len(a1) > 80:
            a1 = a1[:79] + '...'
        if len(a2) > 80:
            a2 = a2[:79] + '...'
        mismatch("Value of attributes '%s:%s'" % (ns, name,), a1, a2)


def compare_variables(name, v1, v2):
    compare_lists("Dimensions for '%s'" % (name,), v1.dimensions, v2.dimensions)

    if v1.datatype != v2.datatype:
        mismatch("Type of variable '%s'" % (name,), v1.datatype, v2.datatype)

    if compare_lists("Variable '%s' attributes" % (name,), v1.ncattrs(), v2.ncattrs()):
        for a in v1.ncattrs():
            compare_attributes(name, a, v1.getncattr(a), v2.getncattr(a))

    vals1 = v1[:]
    vals2 = v2[:]

    if vals1.size != vals2.size:
        mismatch("Size of variable '%s'" % (name,), vals1.size, vals2.size)

    if not (vals1 == vals2).all():
        vals1 = vals1.flatten()
        vals2 = vals2.flatten()
        idx = numpy.nonzero(vals1 - vals2)[0][0]
        if idx < len(vals1) and idx < len(vals2):
            mismatch("Value for variable '%s', first difference at index %s" % (name, idx), vals1[idx], vals2[idx])


def compare_dimensions(name, d1, d2):
    if len(d1) != len(d2):
        mismatch("Length of dimension '%s'" % (name,), len(d1), len(d2))


def check_file(nc, path):

    if len(nc.groups):
        error("Groups not supported (file %s)" % (path,))

    if len(nc.cmptypes):
        error("Compound types not supported (file %s)" % (path,))

    if len(nc.vltypes):
        error("Variable-length types not supported (file %s)" % (path,))


def compare_files(nc1, nc2):

    check_file(nc1, sys.argv[1])
    check_file(nc2, sys.argv[2])

    dims1 = nc1.dimensions
    dims2 = nc2.dimensions

    if compare_lists("Dimensions", dims1.keys(), dims2.keys()):
        for k in dims2.keys():
            compare_dimensions(k, dims1[k], dims2[k])

    vars1 = nc1.variables
    vars2 = nc2.variables

    if compare_lists("Variables", vars1.keys(), vars2.keys()):
        for k in vars1.keys():
            compare_variables(k, vars1[k], vars2[k])

    if compare_lists("Global attributes", nc1.ncattrs(), nc2.ncattrs()):
        for a in nc1.ncattrs():
            compare_attributes("", a, nc1.getncattr(a), nc2.getncattr(a))

    # Other things to checks
    # print nc1.data_model, nc1.disk_format
    # print nc1.parent, nc1.vltypes


nc1 = Dataset(sys.argv[1], 'r')
nc2 = Dataset(sys.argv[2], 'r')

compare_files(nc1, nc2)

if ERRORS:
    sys.exit(1)



# -*- coding: utf-8 -*-
# Program to read NEMO ocean model output temperature field file (netCDF3),
# Requirements:
# 1)convert it to netcdf4 and write one output variable per file.
# 2)Output files should also pass CF checker and CMIP conventions (and possibly OGC).
# 3) Mars attributes should be clearly identified 
# 4) time should be handled (forecast time, assimilation window etc)
# Use an approach whereby various attributes/additional variables can be added to output NetCDF files by calls to functions
#
# K Marsh 23/9/15
#
# Added option to handle multiple input files, input directory and output directory  
#
# K Marsh 2/6/16
#
#*****************************************************************
from netCDF4 import Dataset
from netCDF4 import num2date
import datetime
import MySQLdb
import getopt
import sys
import glob


def add_ensemble(fid, ens_num, ens_len):
    fid.createDimension('ensemble', ens_len)
    fid.createVariable('realization', 'i', 'ensemble')
    fid.variables['realization'].setncattr('standard_name', 'realization')
    fid.variables['realization'].setncattr('long_name', "Number of the simulation in the ensemble")
    fid.variables['realization'][:] = ens_num
    return    

def add_mars_atts(fid, att_dict, var):
    st_date = fid.variables['atime'][:]
    date_str, time_str = str(num2date(st_date, fid.variables['atime'].units)).split()
    for item_att in att_dict.keys():
        if item_att == "mars_date" :
            print 'set date', date_str
            fid.variables[var].setncattr(item_att, date_str)
            continue
        if item_att == "mars_time":
            fid.variables[var].setncattr(item_att, time_str)
            continue
        if item_att == "mars_level":
            fid.variables[var].setncattr(item_att, str(fid.variables['deptht'][:]))
            continue        
        fid.variables[var].setncattr(item_att, att_dict[item_att])
    return

def modify_time(fid, var):
    lDebugFlag = True 
    fid.renameVariable('time_counter', 'time')
    fid.renameVariable('time_counter_bnds', 'time_bnds')
    print dir(fid)
    fid.renameDimension('time_counter','time')
    if lDebugFlag: 
        print fid.variables['time_bnds'][:]
    fid.variables['time'].setncattr("bounds", "time_bnds")
    data_var = fid.variables[var]
    for att in data_var.ncattrs():
        val = data_var.getncattr(att)
        print "att,val",att,val
        if "coordinates" in att and "time_counter" in val:
            val_new = val.replace("time_counter", "time")
            data_var.setncattr("coordinates", val_new)
            print "set time_counter to time"
    fid.createVariable('atime', 'd',)
    fid.variables['atime'].setncattr("standard_name", "forecast_reference_time")
    fid.variables['atime'].setncattr("units", fid.variables['time'].getncattr('units'))
    if lDebugFlag:
        print "** **",fid.variables['time_bnds'][0][0],fid.variables['time_bnds'][0][1]
    fid.variables['atime'][:]=fid.variables['time_bnds'][0][0]
    if lDebugFlag:
        print"***** fid atime ", fid.variables['atime'][:],fid.variables['atime'].shape
    return

def add_assimilation_window(fid, var):
    fid.createVariable('assimilation_window_start', 'd',)
    fid.variables['assimilation_window_start'].setncattr("long_name", "assimilation window start")
    fid.variables['assimilation_window_start'].setncattr("units", fid.variables['time'].getncattr('units'))
    fid.variables['assimilation_window_start'][:] = fid.variables['time_bnds'][0, 0]
    fid.createVariable('assimilation_window_end', 'd',)
    fid.variables['assimilation_window_end'].setncattr("long_name", "assimilation window end")
    fid.variables['assimilation_window_end'].setncattr("units", fid.variables['time'].getncattr('units'))
    fid.variables['assimilation_window_end'][:] = fid.variables['time_bnds'][0, 1]
    return

# Python script to perform a simple lookup on the ecmwf param database for a
# given paramID and return the corresponding CF Standard Name. Databases are
# opened as read-only
#


def db_lookup(db_name,host_name,user_name,pass_name,param_num):

    try:
        db = MySQLdb.connect(host = host_name, # your host, usually localhost
                     user = user_name, # your username
                      passwd = pass_name, # your password
                      db = db_name) # name of the data base

    except MySQLdb.Error, e:
  
        print "Error %d: %s" % (e.args[0],e.args[1])
        sys.exit(1)
#
# create a Cursor object to execute all the queries required
#
    cur = db.cursor() 
#
# List parameter from tables in the database
#

    print "Getting CF name for GRIB1 parameter number ", param_num
    paramID = str(param_num)
    query = "SELECT name, grib1_ecmwf FROM cf WHERE grib1_ecmwf = " + paramID
    cur.execute(query)
    desc = cur.description
    print "%s %3s" % (desc[0][0], desc[1][0])
#
# print all the first cell of all the rows
#
    for row in cur.fetchall() :
        print "CF Standard Name: %s  GRIB1 Code: %s \n" % (row[0],row[1])
    db.close()
    return row[0]


def main():
    """
     main part of the program; take an output NEMO file and split by variable
    """
#
# Read configuration file; also build dictionary to hold MARS-specific 
# placeholder metadata 
#
    lDebugFlag = False
    options, remainder = getopt.getopt(sys.argv[1:],'c:')
    if len(options) ==0:
        print "Option required; Exiting"
        sys.exit()
    for opt, arg in options:
        print opt,arg
        if opt in ('-c'):
           cf_cfg_fname = arg
           print "Config file is ",cf_cfg_fname
        else:
            print "Config file required; Exiting"
            sys.exit()
    try:
        cfg_file=open(cf_cfg_fname,"r")
    except:
        print "File to process does not exit; Exiting"
        sys.exit()
    lines=cfg_file.readlines()
    mars_dict={}
    at_d={}
    var_dict={}
    fnames=[]
    op_dir=""
    for line in lines:
        if line.startswith("#") or len(line.strip()) == 0 : # comment/empty lines: 
            continue  
        elif line.startswith("\'"): # "Env: " line
            option, value = line.split("=")
            o=option.strip()
            v=value.strip()
            os.environ[o] ="$"+o+":"+v            
        else:
            if lDebugFlag:
                print line
            option, value = line.split("=")
            o=option.strip()
            v=value.strip()
            if o == "db_name":
                db_name = v
            elif o == "host_name":
                host_name = v
            elif o == "user_name":
                 user_name = v
            elif o == "pass_name":
                pass_name =v
            elif o == "mars_type":
                 mars_dict["mars_type"] = v                 
            elif o == "mars_class":
                mars_dict["mars_class"] = v
            elif o == "mars_stream":
                 mars_dict["mars_stream"] = v
            elif o == "mars_expver":
                mars_dict["mars_expver"] =v
            elif o == "mars_date":
                 mars_dict["mars_date"] = v                  
            elif o == "mars_time":
                mars_dict["mars_time"] = v
            elif o == "mars_step":
                 mars_dict["mars_step"] = v
            elif o == "mars_number":
                mars_dict["mars_number"] =v
            elif o == "mars_levelist":
                 mars_dict["mars_levelist"] = v   
            elif o == "mars_levtype":
                mars_dict["mars_levtype"] = v
            elif o == "mars_param":
                 mars_dict["mars_param"] = v
            elif o == "fnames":
                fnames.append(v)
            elif o == "input_dir"
                fnames = glob.glob(v+"\/*.nc")
            elif o == "output_dir" 
                op_dir = v
            elif o == "global_attributes_Conventions":
                 at_d["Conventions"] = v              
            elif o == "global_attributes_title":
                 at_d["title"] = v      
            elif o == "global_attributes_institution":
                 at_d["institution"] = v      
            elif o == "global_attributes_references":
                 at_d["references"] = v      
            elif o == "global_attributes_source":
                 at_d["source"] = v  
            elif o == "global_attributes_history":
                 at_d["history"] = v      
            elif o == "global_attributes_comment":
                 at_d["comment"] = v                                                      
            elif o == "nemo_var_name":
                 var_dict[v.split(":")[0]]= [v.split(":")[1],v.split(":")[2],v.split(":")[3]]   
            else:
                print "Warning: Unmatched option"
    cfg_file.close()
    if len(fnames) == 0:
        print "No files to process: exiting"
        sys.exit()
    if op_dir == "":
        print "No output directory specified: exiting"
        sys.exit()      
    if op_dir.endswith("\/"):
        continue
    else:
        op_dir =op_dir + "/"
          
    if len(mars_dict) != 11:
        print "Missing Mars elements: exiting"
        sys.exit()
    if lDebugFlag:
        print "MARS dictionary is :", mars_dict
#
# get current date for 'History' global attribute
#
    now = datetime.datetime.now()
    date_now = ("%s" % now)
    date_now_iso = ("%s" % now.isoformat())
    date_now_history = ("%s-%s-%s %s:%s" % (now.year, now.month, now.day, now.hour, now.minute ))

#
#input filename list for testing
#
# files are output to /scratch/ma/makm/nemo_cfg/split_data_cf/
#
    file_count = 0
    for fname in fnames:
        file_count = file_count + 1
        fname_out = op_dir+"a"+(fname.split("/")[-1]).split(".")[0]
        dsin = Dataset(fname, "r")
#
#copy existing file global attributes to output files
#
        nc_global_attrs = dsin.ncattrs()
#        
# list of files to process -only those specified in config file with CF standard name       
#        
        var_list = []
        for v_name, varin in dsin.variables.iteritems():
            if v_name in var_dict.keys():
                var_list.append(str(v_name)) 
        print "Variables to process: ",var_list
#
# This is the required list of variables needed in all output 'split' files:
#
        req_list = ['nav_lon', 'nav_lat','deptht','time_counter', 'time_counter_bnds']
        process_list = [item for item in var_list if item not in req_list]
        nvar = 0
        icount = 0
#
# loop over required variables which are not required in every file
#
        for p_name in process_list:
            icount = icount + 1
#
# loop over variable items in the netcdf file; use string rather than unicode 
#
            for v_name, varin in dsin.variables.iteritems():
                v_name_str = str(v_name)
#
# if a surface filed, skip for now as need to rework the dimensions
#
                if v_name_str[0:2] == "so": 
                    print "skip surface field ", v_name_str
                    continue
#
# if matches a process variable name, open a new file for output
#
                if v_name_str == p_name:
                    print "processing ", icount, " ", v_name_str, type(v_name_str)
                    print "writing to "+ fname_out + "_reformat_time_cat_" + v_name_str + ".nc"
                    dsout = Dataset(fname_out + "_reformat_time_cat_" + v_name_str + ".nc", "w", format = "NETCDF3_CLASSIC")
#
# add global attributes from original file
#
                    if len(nc_global_attrs) > 0:
                        for ncattr in nc_global_attrs:
                            dsout.setncattr(ncattr, nc_global_attrs[ncattr])
#
# Add global metadata
# Delete existing history
#
                    if "history" in at_d:
                       del at_d["history"]

                    for key in at_d:
                        dsout.setncattr(key, at_d[key])
#
# write out the dimensions
#
                    for dname, the_dim in dsin.dimensions.iteritems():
                        dsout.createDimension(str(dname), len(the_dim)) 
                    add_ensemble(dsout, file_count, 1)
#
# iterate again to write out the required co-ordinate variables
#
                    for v_name_req, varin_req in dsin.variables.iteritems():        
                        if str(v_name_req) in req_list:
                            if "_FillValue" in varin_req.ncattrs() :                      
                                f_val = getattr(varin_req, "_FillValue")
                                outVar = dsout.createVariable(str(v_name_req), \
			        varin_req.dtype, varin_req.dimensions, fill_value = f_val)
                            else:
                                outVar = dsout.createVariable(str(v_name_req), \
			        varin_req.dtype, varin_req.dimensions)
#
# Writing out required co-ordinate Variable: 
#
                            outVar[:] = varin_req[:]
#
# Have to set variable attributes one at a time; _FillValue was not set correctly; 
# title is not a CF variable attribute
#
                            for ncattr in varin_req.ncattrs():
                                if ncattr == "_FillValue" or ncattr == "title": 
                                    continue
#
# TODO add CF standard name attribute based on NEMO-> CF mapping 
#
                                if ncattr == "standard_name":
                                    outVar.setncattr("NEMO_standard_name", varin_req.getncattr(ncattr))
                                    continue                           
#
# Setting attributes for required co-ordinate variable attribute: 
#
                                outVar.setncattr(ncattr, varin_req.getncattr(ncattr))
#
# write out the 'to process' variable  - v_name_str is the original variable name; 
# _FillValue has to be handled carefully and set in the createVariable call.
#
                    if "_FillValue" in varin.ncattrs():
                        varin1 = ['ensemble',]
                        for x in varin.dimensions:
                            varin1.append(x)
                        f_val = getattr(varin, "_FillValue")
                        outVar = dsout.createVariable("data", varin.dtype, varin1, fill_value = f_val)
                    else:
                        outVar = dsout.createVariable("data", varin.dtype, varin1)
                    print "Writing output variable", v_name_str,varin1, " as \"data\"" 
                    outVar[:] = varin[:] 
#
# Have to set variable attributes one at a time
#
                    outVar.setncattr("NEMO_variable_name", v_name_str)
                    for ncattr in varin.ncattrs():
#
#ignore title attributes for variables as this contravenes CF
#ignore _FillValue attributes for variables as this is not set correctly
#                    
                        if ncattr == "_FillValue" or ncattr == "title": 
                            continue
                        if ncattr == "standard_name":
                            outVar.setncattr("NEMO_standard_name", varin.getncattr(ncattr))
                            continue
                        if ncattr == "coordinates":
                            outVar.setncattr(ncattr, "atime " + varin.getncattr(ncattr))
                            continue
                        outVar.setncattr(ncattr, varin.getncattr(ncattr))
#
# if forecast fields, modify time axis accordingly
#
                    modify_time(dsout, "data")
                    
#
# Using dummy ID -hardcoded in script as not all cf names have grib mapping
# add cf standard_name placeholder
#
                    cf_name=var_dict[v_name][0]
                    print "CF Name is ",cf_name
                    grib_param_id = var_dict[v_name][1]
                    grib_param_id_str = str(grib_param_id)
                    mars_dict['mars_param'] = grib_param_id_str
#                    cf_name=db_lookup(db_name,host_name,user_name,pass_name,grib_param_id_str)
                    add_mars_atts(dsout, mars_dict, "data")
                    outVar.setncattr("standard_name",cf_name)
                    print dsout.dimensions
                    print "closing output file", fname_out
                    dsout.close()
                    f_out=fname_out + "_reformat_time_cat_" + v_name_str + ".nc"
                    print f_out
#                    dsout1 = Dataset(f_out,"a")
#                    print dsout1.data_model
#                    print dsout1.dimensions
#                    dsout1.renameDimension(u'time_counter',u'time')
#                    dsout1.close()
                    nvar = nvar + 1
                    print "Variables processed/total: ",nvar,len(process_list)
  
#
# have processed this 'process' variable, so exit loop and do the next
#
                    if lDebugFlag:
                        break
#
# for testing, just need to output the first two variables from the input file
#
            if lDebugFlag: 
                break
        print "Variables Processed/Total: ", nvar,len(process_list)


if __name__ == "__main__":
    main()



